@@ -100,9 +100,10 @@ foreach $variable (keys %{ $parsedconfig{"grid-manager"} } ) {
 foreach $variable (keys %{ $parsedconfig{"infosys"} } ) {
    $config{$variable} = $parsedconfig{"infosys"}{$variable};
 }
-foreach $variable (keys %{ $parsedconfig{"cluster"} } ) {
-   $config{$variable} = $parsedconfig{"cluster"}{$variable};
-}
+#better no to take cluster block values for the queue block
+#foreach $variable (keys %{ $parsedconfig{"cluster"} } ) {
+#   $config{$variable} = $parsedconfig{"cluster"}{$variable};
+#}
 foreach $variable (keys %{ $parsedconfig{"queue/".$config{queue}} } ) {
    $config{$variable} = $parsedconfig{"queue/".$config{queue}}{$variable};
 }
@@ -410,7 +411,7 @@ foreach $user (keys %gridareas) {
     	    }								
       # "ordinary" disk 						 
       } else {  							 
-    	    $diskspace =`df -k $gridarea 2>/dev/null`;    	    	
+    	    $diskspace =`df -k -P $gridarea 2>/dev/null`;    	    	
 	    if ($? != 0) {                
 		&infosys_shared::write_log("Failed checking diskspace for user=$user, gridarea=$gridarea");
 		$diskspace = 0;
@@ -528,13 +529,41 @@ sub queueldif {
     }	
 
     # nordugrid-queue-nodecpu
-    $config{nodecpu} and print "nordugrid-queue-nodecpu: $config{nodecpu}\n";
+    my ($modelname,$mhz);
+    if ($config{nodecpu}=~/adotf/i) {
+       unless (open  CPUINFO, "</proc/cpuinfo") {
+          $config{loglevel} and  &infosys_shared::write_log("error in opening /proc/cpuinfo");
+          die "Error in opening /proc/cpuinfo";
+       }
+       while (my $line= <CPUINFO>) {
+          if ($line=~/^model name\s+:\s+(.*)$/) {
+             $modelname=$1;
+          }
+          if ($line=~/^cpu MHz\s+:\s+(.*)$/) {
+             $mhz=$1;
+         }
+       }
+       close CPUINFO;
+       $nodecpu = "$modelname @ $mhz MHz";
+       print "nordugrid-queue-nodecpu: $nodecpu\n";
+    }
+    else {
+       $config{nodecpu} and print "nordugrid-queue-nodecpu: $config{nodecpu}\n";
+    }
 
     # nordugrid-queue-nodememory
     $config{nodememory} and print "nordugrid-queue-nodememory: $config{nodememory}\n";
-
+    
     # nordugrid-queue-architecture
-    $config{architecture} and print "nordugrid-queue-architecture: $config{architecture}\n";
+    if ($config{architecture}=~/adotf/i) {
+       my $tmparch = `uname -m`;
+       chomp $tmparch;
+       print "nordugrid-queue-architecture: $tmparch\n";
+    }
+    else {                 
+       $config{architecture} and print "nordugrid-queue-architecture: $config{architecture}\n";
+    }
+
 
     #nordugrid-queue-opsys
     my @opsys =  split /\[separator\]/, $config{opsys};
@@ -778,10 +807,10 @@ sub usersldif {
        $key =~ m/\/CN=([^\/]+)(\/Email)?/;
        my $cn = $1;
        $usernumber++;
-       print "dn: nordugrid-authuser-name=", $cn, "_", $usernumber, ", nordugrid-info-group-name=users, ", $config{dn}, "\n";
+       print "dn: nordugrid-authuser-name=", $cn, "...", $usernumber, ", nordugrid-info-group-name=users, ", $config{dn}, "\n";
        print "objectclass: Mds\n";
        print "objectclass: nordugrid-authuser\n";
-       print "nordugrid-authuser-name: ", $cn, "_", $usernumber, "\n";
+       print "nordugrid-authuser-name: ", $cn, "...", $usernumber, "\n";
        print "nordugrid-authuser-sn: $key\n";
        
        #nordugrid-authuser-diskspace
