@@ -201,7 +201,8 @@ sub qju_read_conf_file () {
     my (%parsedconfig) = Shared::arc_conf( $config{conf_file} );
 
     # Copy blocks that are relevant to qju.pl
-    my (@blocks) = ('common', 'grid-manager', 'infosys', 'cluster',
+    # Better not to use cluster block values in the queue block
+    my (@blocks) = ('common', 'grid-manager', 'infosys',
 		    "queue/$config{queue}", 'gridftpd/jobs');
     my ($var);
     foreach my $block ( @blocks ) {
@@ -555,7 +556,7 @@ sub diskspace ($) {
 	    }
 	    # "ordinary" disk
 	} else {
-	    $space =`df -k $path 2>/dev/null`;
+	    $space =`df -k -P $path 2>/dev/null`;
 	    if ($? != 0) {
 		warning("Failed checking diskspace for $path");
 	    }
@@ -875,9 +876,9 @@ sub ldif_user ($$%) {
     $sn =~ m/\/CN=([^\/]+)(\/Email)?/;
     my ($cn) = $1;
     
-    $c{dn} = [ "nordugrid-authuser-name=${cn}_$usernumber, nordugrid-info-group-name=users, $config{dn}" ];
+    $c{dn} = [ "nordugrid-authuser-name=${cn}...$usernumber, nordugrid-info-group-name=users, $config{dn}" ];
     $c{objectclass} = [ 'Mds', 'nordugrid-authuser' ];
-    $c{'nordugrid-authuser-name'} = [ "${cn}_$usernumber" ];
+    $c{'nordugrid-authuser-name'} = [ "${cn}...$usernumber" ];
     $c{'nordugrid-authuser-sn'} = [ "$sn" ];
     
     #nordugrid-authuser-diskspace
